powered by
The vignette of the curvHDR package is displayed using the default PDF file browser. It provides a detailed detailed description of use of the package for gating flow cytometry data using the curvHDR method.
curvHDRvignette()
Matt Wand[email protected], G. Luta[email protected] and U. Naumann[email protected]
if(interactive()) { curvHDRvignette() }
Run the code above in your browser using DataLab